
# sentry-dingtalk-ecool

配置sentry 钉钉报警通知

安装 - install

```bash

- pip install sentry-dingtalk-ecool
```

* or docker

```bash
  echo sentry-dingtalk-ecool >> requirements.txt
```

 重新构建或者重启(rebuild or reboot)

效果:

![](截屏2020-08-19%2011.54.40.png)

![](截屏2020-08-19%2013.31.50.png)

* sentry version: 9.0.0
* dingding webhook
* Sentry sending DingTalk. See https://www.dingtalk.com/
* DingTalk is a product of Alibaba Inc.
